package Bundle::Math::Random;
use strict;
use warnings;

$VERSION = '1.01';

1;

__END__

=head1 NAME

Bundle::Math::Random - Bundle of modules related to random numbers

=head1 SYNOPSIS

 perl -MCPAN -e 'install Bundle::Math::Random'

=head1 CONTENTS

Math::LogRand

Math::Rand48

Math::Random

Math::Random::MT

Math::Random::TT800

Math::RandomOrg

Math::TrulyRandom

=head1 DESCRIPTION

This is a bundle of modules related to random numbers.

Please have a look at L<Bundle::Math>.

If you would like to see a specific module included in a future version of
this bundle, please send me an email or use rt.cpan.org.

=head1 AUTHOR

Steffen Mueller E<lt>bundlemath-module at steffen-mueller dot netE<gt>

=cut 
